FlutteremvPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutteremvPlatform
- Implementers
Constructors
- FlutteremvPlatform()
- Constructs a FlutteremvPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateStream → Stream
-
no setter
Methods
-
cancelcardprocess(
) → void -
debitcard(
String amount) → void -
deviceserialnumber(
) → Future< String> -
enterpin(
String amount) → void -
getcardsheme(
String amount) → Future< TransactionMonitor> -
getPlatformVersion(
) → Future< String?> -
initialize(
String masterKey, String pinkey) → Future< TransactionMonitor> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printreceipt(
Print print) → Future< TransactionMonitor> -
startcustomprinting(
List< Widget> template) → Future<TransactionMonitor> -
starteodPrint(
Map< String, dynamic> template) → Future<TransactionMonitor> -
startkeyboard(
{ValueChanged< String> ? onchange, Function? proceed, Function? cancel}) → void -
startpinpad(
{ValueChanged< String> ? onchange, Function? proceed, Function? cancel}) → void -
startprinting(
Print print) → Future< TransactionMonitor> -
startprintjson(
List< Map< template) → Future<String, Object> >TransactionMonitor> -
stopkeyboard(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutteremvPlatform
-
The default instance of FlutteremvPlatform to use.
getter/setter pair